@@ -1,16 +1,12 @@
 from Testing import ZopeTestCase
 from Products.PloneTestCase import ptc
 
-from Products import CMFPlone
-
 from collective.testcaselayer import ptc as tcl_ptc
 
 ptc.setupPloneSite()
 
 class InstallLayer(tcl_ptc.BasePTCLayer):
 
-    _configure_portal = True
-
     def afterSetUp(self):
         ZopeTestCase.installProduct('slideshowfolder')
         ZopeTestCase.installPackage('collective.slideshowfolder')
@@ -35,5 +31,5 @@ class InstallLayer(tcl_ptc.BasePTCLayer):
             title='Bar Image Title',
             description='Bar Image description')
         
-install_layer = InstallLayer([ptc.PloneTestCase.layer])
+install_layer = InstallLayer([tcl_ptc.ptc_layer])
     
